import messagingtoolkit.mms.*;
import net.sourceforge.jwap.PostRequest;
import net.sourceforge.jwap.Response;
import net.sourceforge.jwap.WAPClient;

import java.io.File;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * Send MMS using MM1 protocol to a WAP gateway
 */
public class SendMMS {

    // Change this if you need
    public static final String PATH = "c:\\temp\\";

    public SendMMS() {
        MultimediaMessage mms = new MultimediaMessage();

        // Set the headers
        SetHeaders(mms);

        // Add the contents
        AddContents(mms);

        // Encode the message
        MultimediaMessageEncoder encoder = new MultimediaMessageEncoder();
        encoder.setMessage(mms);

        try {
            encoder.encodeMessage();
            byte[] out = encoder.getMessage();

            // Send the MMS
            sendMMS("10.1.2.3", 9201, "http://mms.telco.com", out);

            // Create the MMS file
            createMmsFile(out, "Sample.mms");
        }
        catch (Exception e) {
            System.out.println(e.getMessage());
        }
    }


    /**
     * Send MMS
     *
     * @param wapGatewayHost Wap gateway
     * @param wapGatewayPort Wap port
     * @param servlet        MMS servlet
     * @param encodedMms     Encoded MMS
     * @throws IllegalStateException Exception
     * @throws IOException           IO Exception
     */
    private void sendMMS(String wapGatewayHost, int wapGatewayPort, String servlet, byte[] encodedMms) throws IllegalStateException, IOException {

        WAPClient wapClient = new WAPClient(wapGatewayHost, wapGatewayPort);
        PostRequest request = new PostRequest(servlet);
        request.setContentType("application/vnd.wap.mms-message");
        request.setRequestBody(encodedMms);

        System.out.println("Connecting to \"" + wapGatewayHost + "\":" + wapGatewayPort + "...");
        wapClient.connect();

        System.out.println("Sending mms message through \"" + servlet + "\"...");
        Response response = wapClient.execute(request);
        byte[] binaryMms = response.getResponseBody();
        wapClient.disconnect();
        try {
            MultimediaMessageDecoder dec = new MultimediaMessageDecoder(binaryMms);
            dec.decodeMessage();
            MultimediaMessage message = dec.getMessage();

            System.out.println("Status: " + response.getStatus());
            System.out.println("Status Text: " + response.getStatusText());

            if (response.getStatus() == 200) {
                System.out.println("Message id: " + message.getMessageId());
                System.out.println("Message sent!");
            } else {
                System.out.println("Message is not sent");
            }

        } catch (Exception e) {
            System.out.println(e.getMessage());
        }

    }


    private void SetHeaders(MultimediaMessage m) {
        // Just going to set the mandatories, and the subject...
        // Type,TransID,Version are all mandatory, and must be the first headers, in this order!

        m.setMessageType(MultimediaMessageConstants.MESSAGE_TYPE_M_SEND_REQ);
        m.setTransactionId("0123456789");
        m.setVersion(MultimediaMessageConstants.MMS_VERSION_10);
        m.setFrom("12345678/TYPE=PLMN");
        m.addToAddress("12345678/TYPE=PLMN");     //at least one To/CC/BCC is mandatory
        m.setSubject("My first test message!");     //subject is optional

        // ContentType is mandatory, and must be last header!  These last 3 lines set the ContentType to
        // application/vnd.wml.multipart.related;type="application/smil";start="<0000>"
        // In case of multipart.mixed, only the first line is needed (and change the constant)

        // Any string will do for the Content-ID, but it must match that used for the presentation part,
        // and it must be Content-ID, it cannot be Content-Location.

        m.setContentType(MultimediaMessageConstants.CONTENT_TYPE_APPLICATION_MULTIPART_RELATED);
        m.setMultipartRelatedType(MultimediaMessageConstants.CONTENT_TYPE_APPLICATION_SMIL); //presentation part is written in SMIL
        m.setPresentationId("<0000>"); // presentation part has Content-ID=<0000>

    }

    private void AddContents(MultimediaMessage m) {

        // This is where the majority of the work is done.  Note that here we are adding the parts of the
        // message in the order we want them to appear.  Actually the presentation part specifies that,
        // but in terminals which cannot understand the presentation part, the order may be significant,
        // so there seems to be no reason to use random order.

  
        // Path where contents are stored assumed to be same as this class...

        // Add SMIL content
        /*
        MultimediaMessageContent smil_part = new MultimediaMessageContent();
        byte[] b1 = readFile(path + "HelloWorld.smil");
        smil_part.setContent(b1, 0, b1.length);
        smil_part.setContentId("<0000>"); //If "<>" are used with this method, the result is Content-ID
        smil_part.setType(MultimediaMessageConstants.CONTENT_TYPE_APPLICATION_SMIL);
        m.addContent(smil_part);
        */

        // Add slide1 text
        MultimediaMessageContent text = new MultimediaMessageContent();
        text.setContent(PATH + "test.txt");
        text.setContentId("test.txt"); //If "<>" are not used with this method, the result is Content-Location
        text.setType(MultimediaMessageConstants.CONTENT_TYPE_TEXT_PLAIN);
        m.addContent(text);
        // Add slide1 image

        MultimediaMessageContent image = new MultimediaMessageContent();
        image.setContent(PATH + "haiyi.jpg");
        image.setContentId("haiyi.jpg");
        image.setType(MultimediaMessageConstants.CONTENT_TYPE_IMAGE_JPEG);
        m.addContent(image);


    }


    public void createMmsFile(byte[] output, String filename) {
        try {
            File f = new File(PATH + filename);
            FileOutputStream out = new FileOutputStream(f);
            out.write(output);
            out.close();
        }
        catch (Exception e) {
            System.out.println(e.getMessage());
        }
    }

    /**
     * Main entry point
     *
     * @param args Program arguments
     */
    public static void main(String[] args) {
        SendMMS sendMMS = new SendMMS();
    }

}
